# scan2wiki
Scan from ScanSnap to SemanticMediaWiki

[![pypi](https://img.shields.io/pypi/pyversions/scan2wiki)](https://pypi.org/project/scan2wiki/)
[![Github Actions Build](https://github.com/WolfgangFahl/scan2wiki/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/scan2wiki/actions?query=workflow%3ABuild+branch%3Amain)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/scan2wiki.svg)](https://github.com/WolfgangFahl/scan2wiki/issues)
[![GitHub issues](https://img.shields.io/github/issues-closed/WolfgangFahl/scan2wiki.svg)](https://github.com/WolfgangFahl/scan2wiki/issues/?q=is%3Aissue+is%3Aclosed)

[![BITPlan](http://wiki.bitplan.com/images/wiki/thumb/3/38/BITPlanLogoFontLessTransparent.png/198px-BITPlanLogoFontLessTransparent.png)](http://www.bitplan.com)


## Links
* [Python](https://www.python.org/)
* [pywikibot](https://pypi.org/project/pywikibot/)
* [scan2wiki on pypi](https://pypi.org/project/scan2wiki)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/scan2wiki)
